package Plugins::InfoBrowserAddons::BBC::ParseLow;

use strict;

use Slim::Formats::XML;
use HTML::Parser;


sub parse {
	my $class  = shift;
	my $http   = shift;

	my $params = $http->params('params');
	my $url    = $params->{'url'};

	my $body = '';
	my $in_content = 0;
	my $break = 1;
	my $first_line = 1;

	my $p = HTML::Parser->new(api_version => 3,
		start_h => [
			sub {
				my $tag  = shift;
				my $attr = shift;

				if ($in_content) {
					if ($tag eq 'hr') {
						$in_content = 0;
					}
					if (!$break && ($tag eq 'p' || $tag eq 'h2')) {
						$body .= "\n\n";
						$break = 1;
					}
				} elsif ($tag eq 'a' && $attr->{'name'} && $attr->{'name'} eq 'startcontent') {
					$in_content = 1;
				}

			}, "tagname,attr"
		],
		text_h => [
			sub {
				my $text = Slim::Formats::XML::unescapeAndTrim(shift);
				
				if ($text && $in_content) {
					if ($first_line) {
						$text = '' if $text eq $params->{'feedTitle'};
						$first_line = 0;
					} else {
						$break = 0;
					}
					my $pad = ($body =~ /\w$/) ? ' ' : '';
					$body = $body . $pad . $text;
				}

			}, "text"
		],
		end_h => [
			sub {
				my $tag = shift;

				if ($in_content && !$break && $tag eq 'h2') {
					$body .= "\n\n";
					$break = 1;
				}

			}, "tagname"
		],
	);

	$p->parse(${$http->contentRef});

	return {
		'type'        => 'opml',
		'items'       => [ {
			'name'        => $params->{'feedTitle'},
			'link'        => $url,
			'description' => $body,
		}]
	};
}

1;
